# -*- coding: utf-8 -*-
"""
Author: Jitesh Gosar
"""
import glob
import numpy as np
import cv2


class Image2Video:
    def __init__(self, input_path, output_path, fps, size):
        self.input_path = input_path
        self.output_path = output_path
        self.fps = fps
        self.size = size
    
    @staticmethod
    def fast(path, fps = 24):
        # path = "/home/jitesh/3d/blender/hospital_3d/animation/cam2"
        txtfiles = []
        img_array = []
        for filename in glob.glob(path+'/*.png'):
            txtfiles.append(filename)
        txtfiles.sort()
        print(txtfiles)
        for filename in txtfiles:
            print(filename)
            img = cv2.imread(filename)
            height, width, layers = img.shape
            size = (width, height)
            img_array.append(img)


        out = cv2.VideoWriter(path+'.mp4',
                            cv2.VideoWriter_fourcc(*'DIVX'), fps, size)

        for i in range(len(img_array)):
            out.write(img_array[i])
        out.release()



import cv2
import os
count = 0

class v2i:
    def run(vid_path, img_path, count: int = 0):
        out_path=os.path.abspath(f'{img_path}/../my_real_measure_all')
        if not os.path.exists(out_path):
            os.makedirs(out_path)
        vid_cap = cv2.VideoCapture(vid_path)
        success, image = vid_cap.read()
        # count = 0
        out_path=os.path.abspath(f'{img_path}/../my_real_measure_all')
        while success:
            cv2.imwrite(f"{out_path}/frame%d.jpg" % count, image)  # save frame as JPEG file
            success, image = vid_cap.read()
            print(f'Read a new frame {count}: ', success)
            count += 1
        return count

if __name__ == "__main__":
    count = 0
    
    path='measure_20200424_161325'
    count = v2i.run(vid_path=f'/home/jitesh/3d/data/my_measure/{path}.mp4',
        img_path=f'/home/jitesh/3d/data/my_measure/{path}',
        count=count)
    path='measure_20200424_161434'
    count = v2i.run(vid_path=f'/home/jitesh/3d/data/my_measure/{path}.mp4',
        img_path=f'/home/jitesh/3d/data/my_measure/{path}',
        count=count)
    path='measure_20200424_161657'
    count = v2i.run(vid_path=f'/home/jitesh/3d/data/my_measure/{path}.mp4',
        img_path=f'/home/jitesh/3d/data/my_measure/{path}',
        count=count)
    path='measure_20200424_162930'
    count = v2i.run(vid_path=f'/home/jitesh/3d/data/my_measure/{path}.mp4',
        img_path=f'/home/jitesh/3d/data/my_measure/{path}',
        count=count)
    path='measure_20200424_163027'
    count = v2i.run(vid_path=f'/home/jitesh/3d/data/my_measure/{path}.mp4',
        img_path=f'/home/jitesh/3d/data/my_measure/{path}',
        count=count)
